cmd

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 30, 2024 License: Apache-2.0 Imports: 2 Imported by: 0

README

Mac OS X files

.DS_Store

Binaries for programs and plugins

*.exe *.exe~ *.dll *.so *.dylib

Test binary, build with go test -c

*.test

Output of the go coverage tool, specifically when used with LiteIDE

*.out

Project-local glide cache, RE: https://github.com/Masterminds/glide/issues/736

.glide/

Dependency directories (remove the comment below to include it)

vendor/

Go workspace file

go.work go.work.sum

env file

.env

Documentation

Overview

Copyright © 2024 NAME HERE <EMAIL ADDRESS>

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

This section is empty.

Jump to