Documentation
¶
Index ¶
- type BootableInterface
- type BusController
- type BusPublisher
- type BusSubscriber
- func (_m *BusSubscriber) Subscribe(params common.BusSubscriptionParams) error
- func (_m *BusSubscriber) SubscribeAsync(params common.BusSubscriptionParams, transactional bool) error
- func (_m *BusSubscriber) SubscribeOnce(params common.BusSubscriptionParams) error
- func (_m *BusSubscriber) SubscribeOnceAsync(params common.BusSubscriptionParams) error
- func (_m *BusSubscriber) Unsubscribe(params common.BusSubscriptionParams) error
- type ComponentFactoryInterface
- type ComponentInterface
- type ComponentRegistrarInterface
- func (_m *ComponentRegistrarInterface) CreateComponent(ctx *common.Context, config *types.ComponentConfig) (types.ComponentInterface, error)
- func (_m *ComponentRegistrarInterface) GetAllComponents() []types.ComponentInterface
- func (_m *ComponentRegistrarInterface) GetComponent(id string) (types.ComponentInterface, error)
- func (_m *ComponentRegistrarInterface) GetComponentsByType(componentType types.ComponentType) []types.ComponentInterface
- func (_m *ComponentRegistrarInterface) GetFactory(id string) (types.ComponentFactoryInterface, error)
- func (_m *ComponentRegistrarInterface) RegisterFactory(ctx *common.Context, id string, factory types.ComponentFactoryInterface) error
- func (_m *ComponentRegistrarInterface) RemoveComponent(ctx *common.Context, id string) error
- func (_m *ComponentRegistrarInterface) UnregisterFactory(ctx *common.Context, id string) error
- type Database
- func (_m *Database) AvailableVersions() []int
- func (_m *Database) Close() error
- func (_m *Database) Delete(key []byte) error
- func (_m *Database) Get(key []byte) ([]byte, error)
- func (_m *Database) Has(key []byte) (bool, error)
- func (_m *Database) Hash() []byte
- func (_m *Database) IsEmpty() bool
- func (_m *Database) Iterate(fn func([]byte, []byte) bool) error
- func (_m *Database) IterateRange(start []byte, end []byte, ascending bool, fn func([]byte, []byte) bool) error
- func (_m *Database) Load() (int64, error)
- func (_m *Database) LoadVersion(targetVersion int64) (int64, error)
- func (_m *Database) Rollback()
- func (_m *Database) SaveVersion() ([]byte, int64, error)
- func (_m *Database) Set(key []byte, value []byte) error
- func (_m *Database) String() (string, error)
- func (_m *Database) Version() int64
- func (_m *Database) WorkingHash() []byte
- func (_m *Database) WorkingVersion() int64
- type DatabaseFactory
- type EventBusInterface
- func (_m *EventBusInterface) HasCallback(topic string) bool
- func (_m *EventBusInterface) Publish(event common.Event)
- func (_m *EventBusInterface) Subscribe(params common.BusSubscriptionParams) error
- func (_m *EventBusInterface) SubscribeAsync(params common.BusSubscriptionParams, transactional bool) error
- func (_m *EventBusInterface) SubscribeOnce(params common.BusSubscriptionParams) error
- func (_m *EventBusInterface) SubscribeOnceAsync(params common.BusSubscriptionParams) error
- func (_m *EventBusInterface) Unsubscribe(params common.BusSubscriptionParams) error
- func (_m *EventBusInterface) WaitAsync()
- type EventHandler
- type IDGeneratorInterface
- type LoggerInterface
- type MultiStore
- func (_m *MultiStore) AvailableVersions() []int
- func (_m *MultiStore) Close() error
- func (_m *MultiStore) CreateStore(namespace string) (types.Store, bool, error)
- func (_m *MultiStore) Delete(key []byte) error
- func (_m *MultiStore) Get(key []byte) ([]byte, error)
- func (_m *MultiStore) GetStore(namespace []byte) types.Store
- func (_m *MultiStore) GetStoreCount() int
- func (_m *MultiStore) Has(key []byte) (bool, error)
- func (_m *MultiStore) Hash() []byte
- func (_m *MultiStore) IsEmpty() bool
- func (_m *MultiStore) Iterate(fn func([]byte, []byte) bool) error
- func (_m *MultiStore) IterateRange(start []byte, end []byte, ascending bool, fn func([]byte, []byte) bool) error
- func (_m *MultiStore) Load() (int64, error)
- func (_m *MultiStore) LoadVersion(targetVersion int64) (int64, error)
- func (_m *MultiStore) Name() string
- func (_m *MultiStore) Path() string
- func (_m *MultiStore) Rollback()
- func (_m *MultiStore) SaveVersion() ([]byte, int64, error)
- func (_m *MultiStore) Set(key []byte, value []byte) error
- func (_m *MultiStore) String() (string, error)
- func (_m *MultiStore) Version() int64
- func (_m *MultiStore) WorkingHash() []byte
- func (_m *MultiStore) WorkingVersion() int64
- type MutableDatabase
- type PluginInterface
- func (_m *PluginInterface) Description() string
- func (_m *PluginInterface) ID() string
- func (_m *PluginInterface) Initialize(ctx *common.Context, system types.SystemInterface) error
- func (_m *PluginInterface) Name() string
- func (_m *PluginInterface) RegisterResources(ctx *common.Context) error
- func (_m *PluginInterface) Start(ctx *common.Context) error
- func (_m *PluginInterface) Stop(ctx *common.Context) error
- func (_m *PluginInterface) Type() types.ComponentType
- type PluginManagerInterface
- func (_m *PluginManagerInterface) AddPlugin(ctx *common.Context, plugin types.PluginInterface) error
- func (_m *PluginManagerInterface) DiscoverPlugins(ctx *common.Context) ([]types.PluginInterface, error)
- func (_m *PluginManagerInterface) GetPlugin(name string) (types.PluginInterface, error)
- func (_m *PluginManagerInterface) Initialize(ctx *common.Context, system types.SystemInterface) error
- func (_m *PluginManagerInterface) LoadRemotePlugin(ctx *common.Context, pluginURL string) (types.PluginInterface, error)
- func (_m *PluginManagerInterface) RemovePlugin(plugin types.PluginInterface) error
- func (_m *PluginManagerInterface) StartPlugins(ctx *common.Context) error
- func (_m *PluginManagerInterface) StopPlugins(ctx *common.Context) error
- type ReadOnlyDatabase
- func (_m *ReadOnlyDatabase) AvailableVersions() []int
- func (_m *ReadOnlyDatabase) Get(key []byte) ([]byte, error)
- func (_m *ReadOnlyDatabase) Has(key []byte) (bool, error)
- func (_m *ReadOnlyDatabase) Hash() []byte
- func (_m *ReadOnlyDatabase) IsEmpty() bool
- func (_m *ReadOnlyDatabase) Iterate(fn func([]byte, []byte) bool) error
- func (_m *ReadOnlyDatabase) IterateRange(start []byte, end []byte, ascending bool, fn func([]byte, []byte) bool) error
- func (_m *ReadOnlyDatabase) String() (string, error)
- func (_m *ReadOnlyDatabase) Version() int64
- func (_m *ReadOnlyDatabase) WorkingHash() []byte
- func (_m *ReadOnlyDatabase) WorkingVersion() int64
- type StartableInterface
- type Store
- func (_m *Store) AvailableVersions() []int
- func (_m *Store) Close() error
- func (_m *Store) Delete(key []byte) error
- func (_m *Store) Get(key []byte) ([]byte, error)
- func (_m *Store) Has(key []byte) (bool, error)
- func (_m *Store) Hash() []byte
- func (_m *Store) IsEmpty() bool
- func (_m *Store) Iterate(fn func([]byte, []byte) bool) error
- func (_m *Store) IterateRange(start []byte, end []byte, ascending bool, fn func([]byte, []byte) bool) error
- func (_m *Store) Load() (int64, error)
- func (_m *Store) LoadVersion(targetVersion int64) (int64, error)
- func (_m *Store) Name() string
- func (_m *Store) Path() string
- func (_m *Store) Rollback()
- func (_m *Store) SaveVersion() ([]byte, int64, error)
- func (_m *Store) Set(key []byte, value []byte) error
- func (_m *Store) String() (string, error)
- func (_m *Store) Version() int64
- func (_m *Store) WorkingHash() []byte
- func (_m *Store) WorkingVersion() int64
- type StoreFactory
- type SystemComponentInterface
- func (_m *SystemComponentInterface) Description() string
- func (_m *SystemComponentInterface) ID() string
- func (_m *SystemComponentInterface) Initialize(ctx *common.Context, system types.SystemInterface) error
- func (_m *SystemComponentInterface) Name() string
- func (_m *SystemComponentInterface) Type() types.ComponentType
- type SystemInterface
- func (_m *SystemInterface) ComponentRegistry() types.ComponentRegistrarInterface
- func (_m *SystemInterface) Configuration() *types.Configuration
- func (_m *SystemInterface) EventBus() common.EventBusInterface
- func (_m *SystemInterface) ExecuteOperation(ctx *common.Context, operationID string, data *types.SystemOperationInput) (*types.SystemOperationOutput, error)
- func (_m *SystemInterface) Initialize(ctx *common.Context) error
- func (_m *SystemInterface) Logger() common.LoggerInterface
- func (_m *SystemInterface) MultiStore() types.MultiStore
- func (_m *SystemInterface) PluginManager() types.PluginManagerInterface
- func (_m *SystemInterface) RestartService(ctx *common.Context, serviceID string) error
- func (_m *SystemInterface) Start(ctx *common.Context) error
- func (_m *SystemInterface) StartService(ctx *common.Context, serviceID string) error
- func (_m *SystemInterface) Stop(ctx *common.Context) error
- func (_m *SystemInterface) StopService(ctx *common.Context, serviceID string) error
- type SystemOperationInterface
- func (_m *SystemOperationInterface) Description() string
- func (_m *SystemOperationInterface) Execute(ctx *common.Context, input *types.SystemOperationInput) (*types.SystemOperationOutput, error)
- func (_m *SystemOperationInterface) ID() string
- func (_m *SystemOperationInterface) Initialize(ctx *common.Context, system types.SystemInterface) error
- func (_m *SystemOperationInterface) Name() string
- func (_m *SystemOperationInterface) Type() types.ComponentType
- type SystemServiceInterface
- func (_m *SystemServiceInterface) Description() string
- func (_m *SystemServiceInterface) ID() string
- func (_m *SystemServiceInterface) Initialize(ctx *common.Context, system types.SystemInterface) error
- func (_m *SystemServiceInterface) Name() string
- func (_m *SystemServiceInterface) Start(ctx *common.Context) error
- func (_m *SystemServiceInterface) Stop(ctx *common.Context) error
- func (_m *SystemServiceInterface) Type() types.ComponentType
- type VersionedDatabase
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BootableInterface ¶
BootableInterface is an autogenerated mock type for the BootableInterface type
func NewBootableInterface ¶
func NewBootableInterface(t interface {
mock.TestingT
Cleanup(func())
}) *BootableInterface
NewBootableInterface creates a new instance of BootableInterface. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*BootableInterface) Initialize ¶
func (_m *BootableInterface) Initialize(ctx *common.Context) error
Initialize provides a mock function with given fields: ctx
type BusController ¶
BusController is an autogenerated mock type for the BusController type
func NewBusController ¶
func NewBusController(t interface {
mock.TestingT
Cleanup(func())
}) *BusController
NewBusController creates a new instance of BusController. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*BusController) HasCallback ¶
func (_m *BusController) HasCallback(topic string) bool
HasCallback provides a mock function with given fields: topic
func (*BusController) WaitAsync ¶
func (_m *BusController) WaitAsync()
WaitAsync provides a mock function with given fields:
type BusPublisher ¶
BusPublisher is an autogenerated mock type for the BusPublisher type
func NewBusPublisher ¶
func NewBusPublisher(t interface {
mock.TestingT
Cleanup(func())
}) *BusPublisher
NewBusPublisher creates a new instance of BusPublisher. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*BusPublisher) Publish ¶
func (_m *BusPublisher) Publish(event common.Event)
Publish provides a mock function with given fields: event
type BusSubscriber ¶
BusSubscriber is an autogenerated mock type for the BusSubscriber type
func NewBusSubscriber ¶
func NewBusSubscriber(t interface {
mock.TestingT
Cleanup(func())
}) *BusSubscriber
NewBusSubscriber creates a new instance of BusSubscriber. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*BusSubscriber) Subscribe ¶
func (_m *BusSubscriber) Subscribe(params common.BusSubscriptionParams) error
Subscribe provides a mock function with given fields: params
func (*BusSubscriber) SubscribeAsync ¶
func (_m *BusSubscriber) SubscribeAsync(params common.BusSubscriptionParams, transactional bool) error
SubscribeAsync provides a mock function with given fields: params, transactional
func (*BusSubscriber) SubscribeOnce ¶
func (_m *BusSubscriber) SubscribeOnce(params common.BusSubscriptionParams) error
SubscribeOnce provides a mock function with given fields: params
func (*BusSubscriber) SubscribeOnceAsync ¶
func (_m *BusSubscriber) SubscribeOnceAsync(params common.BusSubscriptionParams) error
SubscribeOnceAsync provides a mock function with given fields: params
func (*BusSubscriber) Unsubscribe ¶
func (_m *BusSubscriber) Unsubscribe(params common.BusSubscriptionParams) error
Unsubscribe provides a mock function with given fields: params
type ComponentFactoryInterface ¶
ComponentFactoryInterface is an autogenerated mock type for the ComponentFactoryInterface type
func NewComponentFactoryInterface ¶
func NewComponentFactoryInterface(t interface {
mock.TestingT
Cleanup(func())
}) *ComponentFactoryInterface
NewComponentFactoryInterface creates a new instance of ComponentFactoryInterface. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*ComponentFactoryInterface) CreateComponent ¶
func (_m *ComponentFactoryInterface) CreateComponent(config *types.ComponentConfig) (types.ComponentInterface, error)
CreateComponent provides a mock function with given fields: config
type ComponentInterface ¶
ComponentInterface is an autogenerated mock type for the ComponentInterface type
func NewComponentInterface ¶
func NewComponentInterface(t interface {
mock.TestingT
Cleanup(func())
}) *ComponentInterface
NewComponentInterface creates a new instance of ComponentInterface. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*ComponentInterface) Description ¶
func (_m *ComponentInterface) Description() string
Description provides a mock function with given fields:
func (*ComponentInterface) ID ¶
func (_m *ComponentInterface) ID() string
ID provides a mock function with given fields:
func (*ComponentInterface) Name ¶
func (_m *ComponentInterface) Name() string
Name provides a mock function with given fields:
func (*ComponentInterface) Type ¶
func (_m *ComponentInterface) Type() types.ComponentType
Type provides a mock function with given fields:
type ComponentRegistrarInterface ¶
ComponentRegistrarInterface is an autogenerated mock type for the ComponentRegistrarInterface type
func NewComponentRegistrarInterface ¶
func NewComponentRegistrarInterface(t interface {
mock.TestingT
Cleanup(func())
}) *ComponentRegistrarInterface
NewComponentRegistrarInterface creates a new instance of ComponentRegistrarInterface. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*ComponentRegistrarInterface) CreateComponent ¶
func (_m *ComponentRegistrarInterface) CreateComponent(ctx *common.Context, config *types.ComponentConfig) (types.ComponentInterface, error)
CreateComponent provides a mock function with given fields: ctx, config
func (*ComponentRegistrarInterface) GetAllComponents ¶
func (_m *ComponentRegistrarInterface) GetAllComponents() []types.ComponentInterface
GetAllComponents provides a mock function with given fields:
func (*ComponentRegistrarInterface) GetComponent ¶
func (_m *ComponentRegistrarInterface) GetComponent(id string) (types.ComponentInterface, error)
GetComponent provides a mock function with given fields: id
func (*ComponentRegistrarInterface) GetComponentsByType ¶
func (_m *ComponentRegistrarInterface) GetComponentsByType(componentType types.ComponentType) []types.ComponentInterface
GetComponentsByType provides a mock function with given fields: componentType
func (*ComponentRegistrarInterface) GetFactory ¶
func (_m *ComponentRegistrarInterface) GetFactory(id string) (types.ComponentFactoryInterface, error)
GetFactory provides a mock function with given fields: id
func (*ComponentRegistrarInterface) RegisterFactory ¶
func (_m *ComponentRegistrarInterface) RegisterFactory(ctx *common.Context, id string, factory types.ComponentFactoryInterface) error
RegisterFactory provides a mock function with given fields: ctx, id, factory
func (*ComponentRegistrarInterface) RemoveComponent ¶
func (_m *ComponentRegistrarInterface) RemoveComponent(ctx *common.Context, id string) error
RemoveComponent provides a mock function with given fields: ctx, id
func (*ComponentRegistrarInterface) UnregisterFactory ¶
func (_m *ComponentRegistrarInterface) UnregisterFactory(ctx *common.Context, id string) error
UnregisterFactory provides a mock function with given fields: ctx, id
type Database ¶
Database is an autogenerated mock type for the Database type
func NewDatabase ¶
NewDatabase creates a new instance of Database. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Database) AvailableVersions ¶
AvailableVersions provides a mock function with given fields:
func (*Database) IterateRange ¶
func (_m *Database) IterateRange(start []byte, end []byte, ascending bool, fn func([]byte, []byte) bool) error
IterateRange provides a mock function with given fields: start, end, ascending, fn
func (*Database) LoadVersion ¶
LoadVersion provides a mock function with given fields: targetVersion
func (*Database) Rollback ¶
func (_m *Database) Rollback()
Rollback provides a mock function with given fields:
func (*Database) SaveVersion ¶
SaveVersion provides a mock function with given fields:
func (*Database) WorkingHash ¶
WorkingHash provides a mock function with given fields:
func (*Database) WorkingVersion ¶
WorkingVersion provides a mock function with given fields:
type DatabaseFactory ¶
DatabaseFactory is an autogenerated mock type for the DatabaseFactory type
func NewDatabaseFactory ¶
func NewDatabaseFactory(t interface {
mock.TestingT
Cleanup(func())
}) *DatabaseFactory
NewDatabaseFactory creates a new instance of DatabaseFactory. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*DatabaseFactory) CreateDatabase ¶
CreateDatabase provides a mock function with given fields: name, path
type EventBusInterface ¶
EventBusInterface is an autogenerated mock type for the EventBusInterface type
func NewEventBusInterface ¶
func NewEventBusInterface(t interface {
mock.TestingT
Cleanup(func())
}) *EventBusInterface
NewEventBusInterface creates a new instance of EventBusInterface. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*EventBusInterface) HasCallback ¶
func (_m *EventBusInterface) HasCallback(topic string) bool
HasCallback provides a mock function with given fields: topic
func (*EventBusInterface) Publish ¶
func (_m *EventBusInterface) Publish(event common.Event)
Publish provides a mock function with given fields: event
func (*EventBusInterface) Subscribe ¶
func (_m *EventBusInterface) Subscribe(params common.BusSubscriptionParams) error
Subscribe provides a mock function with given fields: params
func (*EventBusInterface) SubscribeAsync ¶
func (_m *EventBusInterface) SubscribeAsync(params common.BusSubscriptionParams, transactional bool) error
SubscribeAsync provides a mock function with given fields: params, transactional
func (*EventBusInterface) SubscribeOnce ¶
func (_m *EventBusInterface) SubscribeOnce(params common.BusSubscriptionParams) error
SubscribeOnce provides a mock function with given fields: params
func (*EventBusInterface) SubscribeOnceAsync ¶
func (_m *EventBusInterface) SubscribeOnceAsync(params common.BusSubscriptionParams) error
SubscribeOnceAsync provides a mock function with given fields: params
func (*EventBusInterface) Unsubscribe ¶
func (_m *EventBusInterface) Unsubscribe(params common.BusSubscriptionParams) error
Unsubscribe provides a mock function with given fields: params
func (*EventBusInterface) WaitAsync ¶
func (_m *EventBusInterface) WaitAsync()
WaitAsync provides a mock function with given fields:
type EventHandler ¶
EventHandler is an autogenerated mock type for the EventHandler type
func NewEventHandler ¶
func NewEventHandler(t interface {
mock.TestingT
Cleanup(func())
}) *EventHandler
NewEventHandler creates a new instance of EventHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*EventHandler) Execute ¶
func (_m *EventHandler) Execute(event common.Event)
Execute provides a mock function with given fields: event
type IDGeneratorInterface ¶
IDGeneratorInterface is an autogenerated mock type for the IDGeneratorInterface type
func NewIDGeneratorInterface ¶
func NewIDGeneratorInterface(t interface {
mock.TestingT
Cleanup(func())
}) *IDGeneratorInterface
NewIDGeneratorInterface creates a new instance of IDGeneratorInterface. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*IDGeneratorInterface) GenerateID ¶
func (_m *IDGeneratorInterface) GenerateID() (string, error)
GenerateID provides a mock function with given fields:
type LoggerInterface ¶
LoggerInterface is an autogenerated mock type for the LoggerInterface type
func NewLoggerInterface ¶
func NewLoggerInterface(t interface {
mock.TestingT
Cleanup(func())
}) *LoggerInterface
NewLoggerInterface creates a new instance of LoggerInterface. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*LoggerInterface) Log ¶
func (_m *LoggerInterface) Log(level common.Level, args ...interface{})
Log provides a mock function with given fields: level, args
type MultiStore ¶
MultiStore is an autogenerated mock type for the MultiStore type
func NewMultiStore ¶
func NewMultiStore(t interface {
mock.TestingT
Cleanup(func())
}) *MultiStore
NewMultiStore creates a new instance of MultiStore. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MultiStore) AvailableVersions ¶
func (_m *MultiStore) AvailableVersions() []int
AvailableVersions provides a mock function with given fields:
func (*MultiStore) Close ¶
func (_m *MultiStore) Close() error
Close provides a mock function with given fields:
func (*MultiStore) CreateStore ¶
CreateStore provides a mock function with given fields: namespace
func (*MultiStore) Delete ¶
func (_m *MultiStore) Delete(key []byte) error
Delete provides a mock function with given fields: key
func (*MultiStore) Get ¶
func (_m *MultiStore) Get(key []byte) ([]byte, error)
Get provides a mock function with given fields: key
func (*MultiStore) GetStore ¶
func (_m *MultiStore) GetStore(namespace []byte) types.Store
GetStore provides a mock function with given fields: namespace
func (*MultiStore) GetStoreCount ¶
func (_m *MultiStore) GetStoreCount() int
GetStoreCount provides a mock function with given fields:
func (*MultiStore) Has ¶
func (_m *MultiStore) Has(key []byte) (bool, error)
Has provides a mock function with given fields: key
func (*MultiStore) Hash ¶
func (_m *MultiStore) Hash() []byte
Hash provides a mock function with given fields:
func (*MultiStore) IsEmpty ¶
func (_m *MultiStore) IsEmpty() bool
IsEmpty provides a mock function with given fields:
func (*MultiStore) Iterate ¶
func (_m *MultiStore) Iterate(fn func([]byte, []byte) bool) error
Iterate provides a mock function with given fields: fn
func (*MultiStore) IterateRange ¶
func (_m *MultiStore) IterateRange(start []byte, end []byte, ascending bool, fn func([]byte, []byte) bool) error
IterateRange provides a mock function with given fields: start, end, ascending, fn
func (*MultiStore) Load ¶
func (_m *MultiStore) Load() (int64, error)
Load provides a mock function with given fields:
func (*MultiStore) LoadVersion ¶
func (_m *MultiStore) LoadVersion(targetVersion int64) (int64, error)
LoadVersion provides a mock function with given fields: targetVersion
func (*MultiStore) Name ¶
func (_m *MultiStore) Name() string
Name provides a mock function with given fields:
func (*MultiStore) Path ¶
func (_m *MultiStore) Path() string
Path provides a mock function with given fields:
func (*MultiStore) Rollback ¶
func (_m *MultiStore) Rollback()
Rollback provides a mock function with given fields:
func (*MultiStore) SaveVersion ¶
func (_m *MultiStore) SaveVersion() ([]byte, int64, error)
SaveVersion provides a mock function with given fields:
func (*MultiStore) Set ¶
func (_m *MultiStore) Set(key []byte, value []byte) error
Set provides a mock function with given fields: key, value
func (*MultiStore) String ¶
func (_m *MultiStore) String() (string, error)
String provides a mock function with given fields:
func (*MultiStore) Version ¶
func (_m *MultiStore) Version() int64
Version provides a mock function with given fields:
func (*MultiStore) WorkingHash ¶
func (_m *MultiStore) WorkingHash() []byte
WorkingHash provides a mock function with given fields:
func (*MultiStore) WorkingVersion ¶
func (_m *MultiStore) WorkingVersion() int64
WorkingVersion provides a mock function with given fields:
type MutableDatabase ¶
MutableDatabase is an autogenerated mock type for the MutableDatabase type
func NewMutableDatabase ¶
func NewMutableDatabase(t interface {
mock.TestingT
Cleanup(func())
}) *MutableDatabase
NewMutableDatabase creates a new instance of MutableDatabase. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MutableDatabase) Delete ¶
func (_m *MutableDatabase) Delete(key []byte) error
Delete provides a mock function with given fields: key
type PluginInterface ¶
PluginInterface is an autogenerated mock type for the PluginInterface type
func NewPluginInterface ¶
func NewPluginInterface(t interface {
mock.TestingT
Cleanup(func())
}) *PluginInterface
NewPluginInterface creates a new instance of PluginInterface. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*PluginInterface) Description ¶
func (_m *PluginInterface) Description() string
Description provides a mock function with given fields:
func (*PluginInterface) ID ¶
func (_m *PluginInterface) ID() string
ID provides a mock function with given fields:
func (*PluginInterface) Initialize ¶
func (_m *PluginInterface) Initialize(ctx *common.Context, system types.SystemInterface) error
Initialize provides a mock function with given fields: ctx, system
func (*PluginInterface) Name ¶
func (_m *PluginInterface) Name() string
Name provides a mock function with given fields:
func (*PluginInterface) RegisterResources ¶
func (_m *PluginInterface) RegisterResources(ctx *common.Context) error
RegisterResources provides a mock function with given fields: ctx
func (*PluginInterface) Start ¶
func (_m *PluginInterface) Start(ctx *common.Context) error
Start provides a mock function with given fields: ctx
func (*PluginInterface) Stop ¶
func (_m *PluginInterface) Stop(ctx *common.Context) error
Stop provides a mock function with given fields: ctx
func (*PluginInterface) Type ¶
func (_m *PluginInterface) Type() types.ComponentType
Type provides a mock function with given fields:
type PluginManagerInterface ¶
PluginManagerInterface is an autogenerated mock type for the PluginManagerInterface type
func NewPluginManagerInterface ¶
func NewPluginManagerInterface(t interface {
mock.TestingT
Cleanup(func())
}) *PluginManagerInterface
NewPluginManagerInterface creates a new instance of PluginManagerInterface. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*PluginManagerInterface) AddPlugin ¶
func (_m *PluginManagerInterface) AddPlugin(ctx *common.Context, plugin types.PluginInterface) error
AddPlugin provides a mock function with given fields: ctx, plugin
func (*PluginManagerInterface) DiscoverPlugins ¶
func (_m *PluginManagerInterface) DiscoverPlugins(ctx *common.Context) ([]types.PluginInterface, error)
DiscoverPlugins provides a mock function with given fields: ctx
func (*PluginManagerInterface) GetPlugin ¶
func (_m *PluginManagerInterface) GetPlugin(name string) (types.PluginInterface, error)
GetPlugin provides a mock function with given fields: name
func (*PluginManagerInterface) Initialize ¶
func (_m *PluginManagerInterface) Initialize(ctx *common.Context, system types.SystemInterface) error
Initialize provides a mock function with given fields: ctx, system
func (*PluginManagerInterface) LoadRemotePlugin ¶
func (_m *PluginManagerInterface) LoadRemotePlugin(ctx *common.Context, pluginURL string) (types.PluginInterface, error)
LoadRemotePlugin provides a mock function with given fields: ctx, pluginURL
func (*PluginManagerInterface) RemovePlugin ¶
func (_m *PluginManagerInterface) RemovePlugin(plugin types.PluginInterface) error
RemovePlugin provides a mock function with given fields: plugin
func (*PluginManagerInterface) StartPlugins ¶
func (_m *PluginManagerInterface) StartPlugins(ctx *common.Context) error
StartPlugins provides a mock function with given fields: ctx
func (*PluginManagerInterface) StopPlugins ¶
func (_m *PluginManagerInterface) StopPlugins(ctx *common.Context) error
StopPlugins provides a mock function with given fields: ctx
type ReadOnlyDatabase ¶
ReadOnlyDatabase is an autogenerated mock type for the ReadOnlyDatabase type
func NewReadOnlyDatabase ¶
func NewReadOnlyDatabase(t interface {
mock.TestingT
Cleanup(func())
}) *ReadOnlyDatabase
NewReadOnlyDatabase creates a new instance of ReadOnlyDatabase. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*ReadOnlyDatabase) AvailableVersions ¶
func (_m *ReadOnlyDatabase) AvailableVersions() []int
AvailableVersions provides a mock function with given fields:
func (*ReadOnlyDatabase) Get ¶
func (_m *ReadOnlyDatabase) Get(key []byte) ([]byte, error)
Get provides a mock function with given fields: key
func (*ReadOnlyDatabase) Has ¶
func (_m *ReadOnlyDatabase) Has(key []byte) (bool, error)
Has provides a mock function with given fields: key
func (*ReadOnlyDatabase) Hash ¶
func (_m *ReadOnlyDatabase) Hash() []byte
Hash provides a mock function with given fields:
func (*ReadOnlyDatabase) IsEmpty ¶
func (_m *ReadOnlyDatabase) IsEmpty() bool
IsEmpty provides a mock function with given fields:
func (*ReadOnlyDatabase) Iterate ¶
func (_m *ReadOnlyDatabase) Iterate(fn func([]byte, []byte) bool) error
Iterate provides a mock function with given fields: fn
func (*ReadOnlyDatabase) IterateRange ¶
func (_m *ReadOnlyDatabase) IterateRange(start []byte, end []byte, ascending bool, fn func([]byte, []byte) bool) error
IterateRange provides a mock function with given fields: start, end, ascending, fn
func (*ReadOnlyDatabase) String ¶
func (_m *ReadOnlyDatabase) String() (string, error)
String provides a mock function with given fields:
func (*ReadOnlyDatabase) Version ¶
func (_m *ReadOnlyDatabase) Version() int64
Version provides a mock function with given fields:
func (*ReadOnlyDatabase) WorkingHash ¶
func (_m *ReadOnlyDatabase) WorkingHash() []byte
WorkingHash provides a mock function with given fields:
func (*ReadOnlyDatabase) WorkingVersion ¶
func (_m *ReadOnlyDatabase) WorkingVersion() int64
WorkingVersion provides a mock function with given fields:
type StartableInterface ¶
StartableInterface is an autogenerated mock type for the StartableInterface type
func NewStartableInterface ¶
func NewStartableInterface(t interface {
mock.TestingT
Cleanup(func())
}) *StartableInterface
NewStartableInterface creates a new instance of StartableInterface. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
type Store ¶
Store is an autogenerated mock type for the Store type
func NewStore ¶
NewStore creates a new instance of Store. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Store) AvailableVersions ¶
AvailableVersions provides a mock function with given fields:
func (*Store) IterateRange ¶
func (_m *Store) IterateRange(start []byte, end []byte, ascending bool, fn func([]byte, []byte) bool) error
IterateRange provides a mock function with given fields: start, end, ascending, fn
func (*Store) LoadVersion ¶
LoadVersion provides a mock function with given fields: targetVersion
func (*Store) Rollback ¶
func (_m *Store) Rollback()
Rollback provides a mock function with given fields:
func (*Store) SaveVersion ¶
SaveVersion provides a mock function with given fields:
func (*Store) WorkingHash ¶
WorkingHash provides a mock function with given fields:
func (*Store) WorkingVersion ¶
WorkingVersion provides a mock function with given fields:
type StoreFactory ¶
StoreFactory is an autogenerated mock type for the StoreFactory type
func NewStoreFactory ¶
func NewStoreFactory(t interface {
mock.TestingT
Cleanup(func())
}) *StoreFactory
NewStoreFactory creates a new instance of StoreFactory. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*StoreFactory) CreateStore ¶
func (_m *StoreFactory) CreateStore(name string) (types.Store, error)
CreateStore provides a mock function with given fields: name
type SystemComponentInterface ¶
SystemComponentInterface is an autogenerated mock type for the SystemComponentInterface type
func NewSystemComponentInterface ¶
func NewSystemComponentInterface(t interface {
mock.TestingT
Cleanup(func())
}) *SystemComponentInterface
NewSystemComponentInterface creates a new instance of SystemComponentInterface. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*SystemComponentInterface) Description ¶
func (_m *SystemComponentInterface) Description() string
Description provides a mock function with given fields:
func (*SystemComponentInterface) ID ¶
func (_m *SystemComponentInterface) ID() string
ID provides a mock function with given fields:
func (*SystemComponentInterface) Initialize ¶
func (_m *SystemComponentInterface) Initialize(ctx *common.Context, system types.SystemInterface) error
Initialize provides a mock function with given fields: ctx, system
func (*SystemComponentInterface) Name ¶
func (_m *SystemComponentInterface) Name() string
Name provides a mock function with given fields:
func (*SystemComponentInterface) Type ¶
func (_m *SystemComponentInterface) Type() types.ComponentType
Type provides a mock function with given fields:
type SystemInterface ¶
SystemInterface is an autogenerated mock type for the SystemInterface type
func NewSystemInterface ¶
func NewSystemInterface(t interface {
mock.TestingT
Cleanup(func())
}) *SystemInterface
NewSystemInterface creates a new instance of SystemInterface. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*SystemInterface) ComponentRegistry ¶
func (_m *SystemInterface) ComponentRegistry() types.ComponentRegistrarInterface
ComponentRegistry provides a mock function with given fields:
func (*SystemInterface) Configuration ¶
func (_m *SystemInterface) Configuration() *types.Configuration
Configuration provides a mock function with given fields:
func (*SystemInterface) EventBus ¶
func (_m *SystemInterface) EventBus() common.EventBusInterface
EventBus provides a mock function with given fields:
func (*SystemInterface) ExecuteOperation ¶
func (_m *SystemInterface) ExecuteOperation(ctx *common.Context, operationID string, data *types.SystemOperationInput) (*types.SystemOperationOutput, error)
ExecuteOperation provides a mock function with given fields: ctx, operationID, data
func (*SystemInterface) Initialize ¶
func (_m *SystemInterface) Initialize(ctx *common.Context) error
Initialize provides a mock function with given fields: ctx
func (*SystemInterface) Logger ¶
func (_m *SystemInterface) Logger() common.LoggerInterface
Logger provides a mock function with given fields:
func (*SystemInterface) MultiStore ¶
func (_m *SystemInterface) MultiStore() types.MultiStore
MultiStore provides a mock function with given fields:
func (*SystemInterface) PluginManager ¶
func (_m *SystemInterface) PluginManager() types.PluginManagerInterface
PluginManager provides a mock function with given fields:
func (*SystemInterface) RestartService ¶
func (_m *SystemInterface) RestartService(ctx *common.Context, serviceID string) error
RestartService provides a mock function with given fields: ctx, serviceID
func (*SystemInterface) Start ¶
func (_m *SystemInterface) Start(ctx *common.Context) error
Start provides a mock function with given fields: ctx
func (*SystemInterface) StartService ¶
func (_m *SystemInterface) StartService(ctx *common.Context, serviceID string) error
StartService provides a mock function with given fields: ctx, serviceID
func (*SystemInterface) Stop ¶
func (_m *SystemInterface) Stop(ctx *common.Context) error
Stop provides a mock function with given fields: ctx
func (*SystemInterface) StopService ¶
func (_m *SystemInterface) StopService(ctx *common.Context, serviceID string) error
StopService provides a mock function with given fields: ctx, serviceID
type SystemOperationInterface ¶
SystemOperationInterface is an autogenerated mock type for the SystemOperationInterface type
func NewSystemOperationInterface ¶
func NewSystemOperationInterface(t interface {
mock.TestingT
Cleanup(func())
}) *SystemOperationInterface
NewSystemOperationInterface creates a new instance of SystemOperationInterface. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*SystemOperationInterface) Description ¶
func (_m *SystemOperationInterface) Description() string
Description provides a mock function with given fields:
func (*SystemOperationInterface) Execute ¶
func (_m *SystemOperationInterface) Execute(ctx *common.Context, input *types.SystemOperationInput) (*types.SystemOperationOutput, error)
Execute provides a mock function with given fields: ctx, input
func (*SystemOperationInterface) ID ¶
func (_m *SystemOperationInterface) ID() string
ID provides a mock function with given fields:
func (*SystemOperationInterface) Initialize ¶
func (_m *SystemOperationInterface) Initialize(ctx *common.Context, system types.SystemInterface) error
Initialize provides a mock function with given fields: ctx, system
func (*SystemOperationInterface) Name ¶
func (_m *SystemOperationInterface) Name() string
Name provides a mock function with given fields:
func (*SystemOperationInterface) Type ¶
func (_m *SystemOperationInterface) Type() types.ComponentType
Type provides a mock function with given fields:
type SystemServiceInterface ¶
SystemServiceInterface is an autogenerated mock type for the SystemServiceInterface type
func NewSystemServiceInterface ¶
func NewSystemServiceInterface(t interface {
mock.TestingT
Cleanup(func())
}) *SystemServiceInterface
NewSystemServiceInterface creates a new instance of SystemServiceInterface. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*SystemServiceInterface) Description ¶
func (_m *SystemServiceInterface) Description() string
Description provides a mock function with given fields:
func (*SystemServiceInterface) ID ¶
func (_m *SystemServiceInterface) ID() string
ID provides a mock function with given fields:
func (*SystemServiceInterface) Initialize ¶
func (_m *SystemServiceInterface) Initialize(ctx *common.Context, system types.SystemInterface) error
Initialize provides a mock function with given fields: ctx, system
func (*SystemServiceInterface) Name ¶
func (_m *SystemServiceInterface) Name() string
Name provides a mock function with given fields:
func (*SystemServiceInterface) Start ¶
func (_m *SystemServiceInterface) Start(ctx *common.Context) error
Start provides a mock function with given fields: ctx
func (*SystemServiceInterface) Stop ¶
func (_m *SystemServiceInterface) Stop(ctx *common.Context) error
Stop provides a mock function with given fields: ctx
func (*SystemServiceInterface) Type ¶
func (_m *SystemServiceInterface) Type() types.ComponentType
Type provides a mock function with given fields:
type VersionedDatabase ¶
VersionedDatabase is an autogenerated mock type for the VersionedDatabase type
func NewVersionedDatabase ¶
func NewVersionedDatabase(t interface {
mock.TestingT
Cleanup(func())
}) *VersionedDatabase
NewVersionedDatabase creates a new instance of VersionedDatabase. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*VersionedDatabase) Load ¶
func (_m *VersionedDatabase) Load() (int64, error)
Load provides a mock function with given fields:
func (*VersionedDatabase) LoadVersion ¶
func (_m *VersionedDatabase) LoadVersion(targetVersion int64) (int64, error)
LoadVersion provides a mock function with given fields: targetVersion
func (*VersionedDatabase) Rollback ¶
func (_m *VersionedDatabase) Rollback()
Rollback provides a mock function with given fields:
func (*VersionedDatabase) SaveVersion ¶
func (_m *VersionedDatabase) SaveVersion() ([]byte, int64, error)
SaveVersion provides a mock function with given fields:
Source Files
¶
- BootableInterface.go
- BusController.go
- BusPublisher.go
- BusSubscriber.go
- ComponentFactoryInterface.go
- ComponentInterface.go
- ComponentRegistrarInterface.go
- Database.go
- DatabaseFactory.go
- EventBusInterface.go
- EventHandler.go
- IDGeneratorInterface.go
- LoggerInterface.go
- MultiStore.go
- MutableDatabase.go
- PluginInterface.go
- PluginManagerInterface.go
- ReadOnlyDatabase.go
- StartableInterface.go
- Store.go
- StoreFactory.go
- SystemComponentInterface.go
- SystemInterface.go
- SystemOperationInterface.go
- SystemServiceInterface.go
- VersionedDatabase.go